@@ -15,18 +15,18 @@ var configExportCmd = &cobra.Command{
 json or yaml file. This exported configuration can be changed,
 and imported again with 'config import' command.`,
 	Args: jsonYamlArg,
-	RunE: python(func(_ *cobra.Command, args []string, d *pythonData) error {
-		settings, err := d.store.Settings.Get()
+	RunE: withStore(func(_ *cobra.Command, args []string, st *store) error {
+		settings, err := st.Settings.Get()
 		if err != nil {
 			return err
 		}
 
-		server, err := d.store.Settings.GetServer()
+		server, err := st.Settings.GetServer()
 		if err != nil {
 			return err
 		}
 
-		auther, err := d.store.Auth.Get(settings.AuthMethod)
+		auther, err := st.Auth.Get(settings.AuthMethod)
 		if err != nil {
 			return err
 		}
@@ -42,5 +42,5 @@ and imported again with 'config import' command.`,
 			return err
 		}
 		return nil
-	}, pythonConfig{}),
+	}, storeOptions{}),
 }
