@@ -1,4 +1,4 @@
-package http
+package fbhttp
 
 import (
 	"io/fs"
